=== modified file 'lib/devscripts/autoland.py'
--- lib/devscripts/autoland.py	2009-09-30 12:34:02 +0000
+++ lib/devscripts/autoland.py	2009-10-06 21:32:44 +0000
@@ -5,6 +5,8 @@
 from launchpadlib.launchpad import (
     Launchpad, EDGE_SERVICE_ROOT, STAGING_SERVICE_ROOT)
 from lazr.uri import URI
+from bzrlib.errors import BzrCommandError
+
 
 # XXX: JonathanLange 2009-09-24: Both of these are available in more recent
 # versions of launchpadlib. When we start using such versions, we should
@@ -42,6 +44,21 @@
             web_mp_uri.path.lstrip('/'))
         return MergeProposal(self._launchpad.load(str(api_mp_uri)))
 
+    def get_merge_proposal_from_branch(self, branch):
+        """Get the merge proposal from the branch."""
+        branch_url = branch.get_public_branch()
+        lp_branch = self._launchpad.branches.getByUrl(
+            url=branch_url)
+        if lp_branch is None:
+            raise BzrCommandError(
+                "No public branch at %s" % branch_url)
+        proposals = lp_branch.landing_targets
+        if len(proposals) != 1:
+            raise BzrCommandError(
+                "The public branch has multiple source merge proposals.  "
+                "You must provide the URL to the one you wish to use.")
+        return MergeProposal(proposals[0])
+
 
 class MergeProposal:
     """Wrapper around launchpadlib `IBranchMergeProposal` for landing."""

=== modified file 'lib/devscripts/ec2test/builtins.py'
--- lib/devscripts/ec2test/builtins.py	2009-10-04 15:40:46 +0000
+++ lib/devscripts/ec2test/builtins.py	2009-10-06 21:32:44 +0000
@@ -10,6 +10,7 @@
 import pdb
 import subprocess
 
+from bzrlib.bzrdir import BzrDir
 from bzrlib.commands import Command
 from bzrlib.errors import BzrCommandError
 from bzrlib.help import help_commands
@@ -322,7 +323,7 @@
             help="Land the branch even if the proposal is not approved."),
         ]
 
-    takes_args = ['merge_proposal']
+    takes_args = ['merge_proposal?']
 
     def _get_landing_command(self, source_url, target_url, commit_message,
                              emails):
@@ -339,7 +340,7 @@
              commit_message, str(source_url)])
         return command
 
-    def run(self, merge_proposal, machine=None,
+    def run(self, merge_proposal=None, machine=None,
             instance_type=DEFAULT_INSTANCE_TYPE, postmortem=False,
             debug=False, commit_text=None, dry_run=False, testfix=False,
             print_commit=False, force=False):
@@ -349,7 +350,13 @@
             raise BzrCommandError(
                 "Cannot specify --print-commit and --dry-run.")
         lander = LaunchpadBranchLander.load()
-        mp = lander.load_merge_proposal(merge_proposal)
+
+        if merge_proposal is None:
+            (tree, bzrbranch, relpath) = (
+                BzrDir.open_containing_tree_or_branch(''))
+            mp = lander.get_merge_proposal_from_branch(bzrbranch)
+        else:
+            mp = lander.load_merge_proposal(merge_proposal)
         if not mp.is_approved:
             if force:
                 print "Merge proposal is not approved, landing anyway."

